# 0.2.0
Получение торговых данных MOEX по акциям, валюте и фьючерсам:
- акции: Real-time market data, HI2 (market concentration)
- фьючерсы: Real-time market data, HI2 (market concentration), FUTOI, SuperCandles
- Валюта: HI2 (market concentration), SuperCandles

Улучшения в интерфейсе и исправление ошибок


# 0.1.0 
Получение торговых данных по акциям на MOEX:
- Справочник интрументов
- Торговая статистика
- Candles (Свечи)

- AlgoPack.TradeStats
- AlgoPack.OrderStats
- AlgoPack.OBStats
